@@ -15,5 +15,8 @@ def gen_case(item=case_list, value=value_list):
     for i in itertools.product(item, value):
         print('输入'.join(i))
 
+def test_print():
+	print("hello package mikezhou !")
+#
 if __name__ == '__main__':
     gen_case()
